pub struct FormLabel { /* private fields */ }Expand description
Form Label
Features required
forms
Example
use yew::prelude::*;
use yew_styles::forms::{
form_label::FormLabel,
form_group::{FormGroup, Orientation},
form_textarea::FormTextArea,
};
use yew_styles::styles::{Palette, Size};
pub struct FormLabelExample {
pub link: ComponentLink<Self>,
pub value: String,
}
pub enum Msg {
Input(String),
}
impl Component for FormLabelExample {
type Message = Msg;
type Properties = ();
fn create(_: Self::Properties, link: ComponentLink<Self>) -> Self {
FormLabelExample {
link,
value: "".to_string(),
}
}
fn update(&mut self, msg: Self::Message) -> ShouldRender {
match msg {
Msg::Input(value) => {
self.value = value;
}
}
true
}
fn change(&mut self, _props: Self::Properties) -> ShouldRender {
false
}
fn view(&self) -> Html {
html!{
<FormGroup orientation=Orientation::Vertical>
<FormLabel
text="Info small textarea"
/>
<FormTextArea placeholder="write here"
value=form_page.value.clone()
textarea_size=Size::Small
textarea_style=Palette::Info
oninput_signal=form_page.link.callback(|e: InputData| Msg::Input(e.value))
/>
</FormGroup>
}
}Trait Implementations
Sourceimpl Component for FormLabel
impl Component for FormLabel
Sourcetype Message = ()
type Message = ()
Messages are used to make Components dynamic and interactive. Simple
Component’s can declare their Message type to be
(). Complex Component’s
commonly use an enum to declare multiple Message types.Sourcetype Properties = Props
type Properties = Props
Properties are the inputs to a Component and should not mutated within a
Component. They are passed to a Component using a JSX-style syntax. Read more
Sourcefn create(props: Self::Properties, _link: ComponentLink<Self>) -> Self
fn create(props: Self::Properties, _link: ComponentLink<Self>) -> Self
Components are created with their properties as well as a
ComponentLink which
can be used to send messages and create callbacks for triggering updates.Sourcefn update(&mut self, _msg: Self::Message) -> ShouldRender
fn update(&mut self, _msg: Self::Message) -> ShouldRender
Components handle messages in their
update method and commonly use this method
to update their state and (optionally) re-render themselves.Sourcefn change(&mut self, props: Self::Properties) -> ShouldRender
fn change(&mut self, props: Self::Properties) -> ShouldRender
When the parent of a Component is re-rendered, it will either be re-created or
receive new properties in the
change lifecycle method. Component’s can choose
to re-render if the new properties are different than the previously
received properties. Most Component’s will use props with a PartialEq
impl and will be implemented like this: Read moreSourcefn view(&self) -> Html
fn view(&self) -> Html
Components define their visual layout using a JSX-style syntax through the use of the
html! procedural macro. The full guide to using the macro can be found in Yew’s
documentation.Auto Trait Implementations
impl !RefUnwindSafe for FormLabel
impl !Send for FormLabel
impl !Sync for FormLabel
impl !UnwindSafe for FormLabel
impl Freeze for FormLabel
impl Unpin for FormLabel
impl UnsafeUnpin for FormLabel